@@ -1,2 +1,2 @@
-from .thenie import Cache
+from .thenie import Cache, Memoize
 from theine_core import BloomFilter
