@@ -1,9 +1,8 @@
 from dataclasses import dataclass
-from typing import Any, Optional, Dict
+from typing import Any
 
 
 @dataclass
 class CachedValue:
     data: Any
     expire: float
-    bucket: Optional[Dict] = None
